Module: Bunto::Convertible
Instance Method Summary collapse
-
#[](property) ⇒ Object
Accessor for data properties by Liquid.
-
#asset_file? ⇒ Boolean
Determine whether the document is an asset file.
-
#coffeescript_file? ⇒ Boolean
Determine whether the document is a CoffeeScript file.
-
#converters ⇒ Object
Determine which converter to use based on this convertible’s extension.
-
#do_layout(payload, layouts) ⇒ Object
Add any necessary layouts to this convertible document.
-
#hook_owner ⇒ Object
returns the owner symbol for hook triggering.
-
#invalid_layout?(layout) ⇒ Boolean
Checks if the layout specified in the document actually exists.
-
#output_ext ⇒ Object
Determine the extension depending on content_type.
-
#place_in_layout? ⇒ Boolean
Determine whether the file should be placed into layouts.
-
#published? ⇒ Boolean
Whether the file is published or not, as indicated in YAML front-matter.
-
#read_yaml(base, name, opts = {}) ⇒ Object
Read the YAML frontmatter.
-
#render_all_layouts(layouts, payload, info) ⇒ Object
Recursively render layouts.
-
#render_liquid(content, payload, info, path) ⇒ Object
Render Liquid in the content.
-
#render_with_liquid? ⇒ Boolean
Determine whether the file should be rendered with Liquid.
-
#sass_file? ⇒ Boolean
Determine whether the document is a Sass file.
-
#to_liquid(attrs = nil) ⇒ Object
Convert this Convertible’s data to a Hash suitable for use by Liquid.
-
#to_s ⇒ Object
Returns the contents as a String.
-
#transform ⇒ Object
Transform the contents based on the content type.
-
#type ⇒ Object
The type of a document, i.e., its classname downcase’d and to_sym’d.
-
#validate_data!(filename) ⇒ Object
rubocop:enable Metrics/AbcSize.
- #validate_permalink!(filename) ⇒ Object
-
#write(dest) ⇒ Object
Write the generated page file to the destination directory.
Instance Method Details
#[](property) ⇒ Object
Accessor for data properties by Liquid.
property - The String name of the property to retrieve.
Returns the String value or nil if the property isn’t included.
236 237 238 239 240 241 242 |
# File 'lib/bunto/convertible.rb', line 236 def [](property) if self.class::ATTRIBUTES_FOR_LIQUID.include?(property) send(property) else data[property] end end |
#asset_file? ⇒ Boolean
Determine whether the document is an asset file. Asset files include CoffeeScript files and Sass/SCSS files.
Returns true if the extname belongs to the set of extensions
that asset files use.
146 147 148 |
# File 'lib/bunto/convertible.rb', line 146 def asset_file? sass_file? || coffeescript_file? end |
#coffeescript_file? ⇒ Boolean
Determine whether the document is a CoffeeScript file.
Returns true if extname == .coffee, false otherwise.
160 161 162 |
# File 'lib/bunto/convertible.rb', line 160 def coffeescript_file? ".coffee" == ext end |
#converters ⇒ Object
Determine which converter to use based on this convertible’s extension.
Returns the Converter instance.
96 97 98 |
# File 'lib/bunto/convertible.rb', line 96 def converters _renderer.converters end |
#do_layout(payload, layouts) ⇒ Object
Add any necessary layouts to this convertible document.
payload - The site payload Drop or Hash. layouts - A Hash of => “layout”.
Returns nothing.
207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/bunto/convertible.rb', line 207 def do_layout(payload, layouts) self.output = _renderer.tap do |renderer| renderer.layouts = layouts renderer.payload = payload end.run Bunto.logger.debug "Post-Render Hooks:", self.relative_path Bunto::Hooks.trigger hook_owner, :post_render, self ensure @_renderer = nil # this will allow the modifications above to disappear end |
#hook_owner ⇒ Object
returns the owner symbol for hook triggering
135 136 137 138 139 |
# File 'lib/bunto/convertible.rb', line 135 def hook_owner if is_a?(Page) :pages end end |
#invalid_layout?(layout) ⇒ Boolean
Checks if the layout specified in the document actually exists
layout - the layout to check
Returns true if the layout is invalid, false if otherwise
183 184 185 |
# File 'lib/bunto/convertible.rb', line 183 def invalid_layout?(layout) !data["layout"].nil? && layout.nil? && !(self.is_a? Bunto::Excerpt) end |
#output_ext ⇒ Object
Determine the extension depending on content_type.
Returns the String extension for the output file.
e.g. ".html" for an HTML output file.
88 89 90 |
# File 'lib/bunto/convertible.rb', line 88 def output_ext _renderer.output_ext end |
#place_in_layout? ⇒ Boolean
Determine whether the file should be placed into layouts.
Returns false if the document is an asset file.
174 175 176 |
# File 'lib/bunto/convertible.rb', line 174 def place_in_layout? !asset_file? end |
#published? ⇒ Boolean
Whether the file is published or not, as indicated in YAML front-matter
27 28 29 |
# File 'lib/bunto/convertible.rb', line 27 def published? !(data.key?("published") && data["published"] == false) end |
#read_yaml(base, name, opts = {}) ⇒ Object
Read the YAML frontmatter.
base - The String path to the dir containing the file. name - The String filename of the file. opts - optional parameter to File.read, default at site configs
Returns nothing. rubocop:disable Metrics/AbcSize
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/bunto/convertible.rb', line 39 def read_yaml(base, name, opts = {}) filename = File.join(base, name) begin self.content = File.read(@path || site.in_source_dir(base, name), Utils.merged_file_read_opts(site, opts)) if content =~ Document::YAML_FRONT_MATTER_REGEXP self.content = $POSTMATCH self.data = SafeYAML.load(Regexp.last_match(1)) end rescue SyntaxError => e Bunto.logger.warn "YAML Exception reading #{filename}: #{e.message}" rescue => e Bunto.logger.warn "Error reading file #{filename}: #{e.message}" end self.data ||= {} validate_data! filename validate_permalink! filename self.data end |
#render_all_layouts(layouts, payload, info) ⇒ Object
Recursively render layouts
layouts - a list of the layouts payload - the payload for Liquid info - the info for Liquid
Returns nothing
194 195 196 197 198 199 |
# File 'lib/bunto/convertible.rb', line 194 def render_all_layouts(layouts, payload, info) _renderer.layouts = layouts self.output = _renderer.place_in_layouts(output, payload, info) ensure @_renderer = nil # this will allow the modifications above to disappear end |
#render_liquid(content, payload, info, path) ⇒ Object
Render Liquid in the content
content - the raw Liquid content to render payload - the payload for Liquid info - the info for Liquid
Returns the converted content
107 108 109 |
# File 'lib/bunto/convertible.rb', line 107 def render_liquid(content, payload, info, path) _renderer.render_liquid(content, payload, info, path) end |
#render_with_liquid? ⇒ Boolean
Determine whether the file should be rendered with Liquid.
Always returns true.
167 168 169 |
# File 'lib/bunto/convertible.rb', line 167 def render_with_liquid? true end |
#sass_file? ⇒ Boolean
Determine whether the document is a Sass file.
Returns true if extname == .sass or .scss, false otherwise.
153 154 155 |
# File 'lib/bunto/convertible.rb', line 153 def sass_file? %w(.sass .scss).include?(ext) end |
#to_liquid(attrs = nil) ⇒ Object
Convert this Convertible’s data to a Hash suitable for use by Liquid.
Returns the Hash representation of this Convertible.
115 116 117 118 119 120 121 122 |
# File 'lib/bunto/convertible.rb', line 115 def to_liquid(attrs = nil) further_data = Hash[(attrs || self.class::ATTRIBUTES_FOR_LIQUID).map do |attribute| [attribute, send(attribute)] end] defaults = site.frontmatter_defaults.all(relative_path, type) Utils.deep_merge_hashes defaults, Utils.deep_merge_hashes(data, further_data) end |
#to_s ⇒ Object
Returns the contents as a String.
22 23 24 |
# File 'lib/bunto/convertible.rb', line 22 def to_s content || "" end |
#transform ⇒ Object
Transform the contents based on the content type.
Returns the transformed contents.
80 81 82 |
# File 'lib/bunto/convertible.rb', line 80 def transform _renderer.transform end |
#type ⇒ Object
The type of a document,
i.e., its classname downcase'd and to_sym'd.
Returns the type of self.
128 129 130 131 132 |
# File 'lib/bunto/convertible.rb', line 128 def type if is_a?(Page) :pages end end |
#validate_data!(filename) ⇒ Object
rubocop:enable Metrics/AbcSize
64 65 66 67 68 69 |
# File 'lib/bunto/convertible.rb', line 64 def validate_data!(filename) unless self.data.is_a?(Hash) raise Errors::InvalidYAMLFrontMatterError, "Invalid YAML front matter in #{filename}" end end |
#validate_permalink!(filename) ⇒ Object
71 72 73 74 75 |
# File 'lib/bunto/convertible.rb', line 71 def validate_permalink!(filename) if self.data["permalink"] && self.data["permalink"].empty? raise Errors::InvalidPermalinkError, "Invalid permalink in #{filename}" end end |
#write(dest) ⇒ Object
Write the generated page file to the destination directory.
dest - The String path to the destination dir.
Returns nothing.
224 225 226 227 228 229 |
# File 'lib/bunto/convertible.rb', line 224 def write(dest) path = destination(dest) FileUtils.mkdir_p(File.dirname(path)) File.write(path, output, :mode => "wb") Bunto::Hooks.trigger hook_owner, :post_write, self end |