Class: Bunto::Layout

Inherits:
Object
  • Object
show all
Includes:
Convertible
Defined in:
lib/bunto/layout.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Convertible

#[], #asset_file?, #coffeescript_file?, #converters, #do_layout, #hook_owner, #invalid_layout?, #output_ext, #place_in_layout?, #published?, #read_yaml, #render_all_layouts, #render_liquid, #render_with_liquid?, #sass_file?, #to_liquid, #to_s, #transform, #type, #validate_data!, #validate_permalink!, #write

Constructor Details

#initialize(site, base, name) ⇒ Layout

Initialize a new Layout.

site - The Site. base - The String path to the source. name - The String filename of the post file.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/bunto/layout.rb', line 31

def initialize(site, base, name)
  @site = site
  @base = base
  @name = name

  if site.theme && site.theme.layouts_path.eql?(base)
    @base_dir = site.theme.root
    @path = site.in_theme_dir(base, name)
  else
    @base_dir = site.source
    @path = site.in_source_dir(base, name)
  end
  @relative_path = @path.sub(@base_dir, "")

  self.data = {}

  process(name)
  read_yaml(base, name)
end

Instance Attribute Details

#contentObject

Gets/Sets the content of this layout.



24
25
26
# File 'lib/bunto/layout.rb', line 24

def content
  @content
end

#dataObject

Gets/Sets the Hash that holds the metadata for this layout.



21
22
23
# File 'lib/bunto/layout.rb', line 21

def data
  @data
end

#extObject

Gets/Sets the extension of this layout.



18
19
20
# File 'lib/bunto/layout.rb', line 18

def ext
  @ext
end

#nameObject (readonly)

Gets the name of this layout.



9
10
11
# File 'lib/bunto/layout.rb', line 9

def name
  @name
end

#pathObject (readonly)

Gets the path to this layout.



12
13
14
# File 'lib/bunto/layout.rb', line 12

def path
  @path
end

#relative_pathObject (readonly)

Gets the path to this layout relative to its base



15
16
17
# File 'lib/bunto/layout.rb', line 15

def relative_path
  @relative_path
end

#siteObject (readonly)

Gets the Site object.



6
7
8
# File 'lib/bunto/layout.rb', line 6

def site
  @site
end

Instance Method Details

#process(name) ⇒ Object

Extract information from the layout filename.

name - The String filename of the layout file.

Returns nothing.



56
57
58
# File 'lib/bunto/layout.rb', line 56

def process(name)
  self.ext = File.extname(name)
end