Method: Bunto::Drops::Drop#keys
- Defined in:
- lib/bunto/drops/drop.rb
#keys ⇒ Object
Generates a list of keys with user content as their values. This gathers up the Drop methods and keys of the mutations and underlying data hashes and performs a set union to ensure a list of unique keys for the Drop.
Returns an Array of unique keys for content for the Drop.
118 119 120 121 122 |
# File 'lib/bunto/drops/drop.rb', line 118 def keys (content_methods | @mutations.keys | fallback_data.keys).flatten end |